@@ -1,11 +1,11 @@
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 __author__ = 'Mitchell Lisle'
 __email__ = 'm.lisle90@gmail.com'
 
 
 from yessql.aiomysql import AioMySQL
 from yessql.aiopostgres.client import AioPostgres
-from yessql.aiopostgres.params import NamedParams
+from yessql.aiopostgres.params import NamedParams, NamedParamsList
 from yessql.config import DatabaseConfig, MySQLConfig, PostgresConfig
 from yessql.logger import logger
 from yessql.postgres import ContextCursor, Postgres
